Presets configuration plugin
============================

.. automodule:: vmshepherd.presets.abstract

.. autoclass:: vmshepherd.presets.abstract.AbstractConfigurationDriver
    :members: _list, _get_preset_spec
    :private-members:
    :show-inheritance:
